package com.tickmark.heap_io_flutter;

import android.content.Context;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

import com.heapanalytics.android.Heap;
import com.heapanalytics.android.config.Options;

import java.util.Map;

/**
 * HeapIoFlutterPlugin
 */
public class HeapIoFlutterPlugin implements FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private Context context;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        onAttached(flutterPluginBinding.getApplicationContext());
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "heap_io_flutter");
        channel.setMethodCallHandler(this);
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("initialize")) {
            Heap.init(context, (String) call.argument("appId"));
            result.success(true);
        } else if (call.method.equals("identify")) {
            Heap.identify((String) call.argument("identity"));
            result.success(true);
        } else if (call.method.equals("track")) {
            Heap.track((String) call.argument("eventName"), (Map<String, String>) call.argument("properties"));
            result.success(true);
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    private void onAttached(Context applicationContext) {
        context = applicationContext;
    }
}
